ScriptLana class final
A class that represents the Tai Tham (Lanna) script.
- Inheritance
-
- Object
- WritingSystem
- Script
- ScriptLana
- Available extensions
Constructors
- ScriptLana()
-
Creates a instance of ScriptLana (Tai Tham (Lanna) script).
constfactory
Properties
- code → String
-
A four-character string representing the ISO 15924 code for the script.
finalinherited
- codeNumeric → String
-
A three-digit string representing the ISO 15924 numeric code for the
script.
finalinherited
- codeOther → String
-
A three-digit string representing the ISO 15924 numeric code for the
script.
no setterinherited
- date → String
-
The date of addition of the script.
finalinherited
- dateTime → DateTime
-
Available on Script, provided by the ScriptGetters extension
Returns a DateTime object parsed from the date string.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- internationalName → String
-
An String representing the international name of the object. This is
typically a English name of the ISO object.
no setterinherited
- iso15924Letter → String
-
Available on Script, provided by the ScriptGetters extension
Returns the ISO 15924 letter code of the script.no setter - iso15924Numeric → String
-
Available on Script, provided by the ScriptGetters extension
Returns the ISO 15924 numeric code of the script.no setter - name → String
-
The common name of the object.
finalinherited
-
namesNative
→ List<
String> ? -
An optional list of objects representing the native names of the object.
no setterinherited
- pva → String?
-
The property value alias for the script.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compareTo(
Script other) → int -
Compares this object to another object.
inherited
-
copyWith(
{String? code, String? codeNumeric, String? date, String? name, String? pva}) → Script -
Available on T, provided by the ScriptCopyWith extension
Creates a copy of this object with the given fields replaced with the new values. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
{JsonCodec codec = const JsonCodec()}) → String -
Returns a JSON-encoded string representation of the object.
inherited
-
toMap(
) → Map< String, String> -
Available on Script, provided by the ScriptJson extension
Converts this object object to a JSON like map. -
toString(
{bool short = true}) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited