isIsoAlphaRegularCode property
bool
get
isIsoAlphaRegularCode
Checks if the object's string representation is a valid ISO code.
Returns true if the object's string representation matches strings that
consist of Latin characters (uppercase or lowercase) and have a length of
3 or more characters, indicating that it is a valid ISO code.
Returns false otherwise.
In terms of this package, it means that it is a valid
ISO code (not codeOther).
Implementation
bool get isIsoAlphaRegularCode => toCode().isIsoAlphaRegularCode;