LangAar class final
A class that represents the Afar language.
- Inheritance
-
- Object
- Language
- NaturalLanguage
- LangAar
- Available extensions
Properties
- bibliographicCode → String?
-
A three-letter string representing the ISO 639-2/B Bibliographic code for
the language, or
nullif no such code exists.finalinherited - code → String
-
A three-letter string representing the Terminological ISO 639-2 code for
the language.
finalinherited
- codeOther → String
-
A two-letter string representing the ISO 639-1 code for the language.
no setterinherited
- codeShort → String
-
A two-letter string representing the ISO 639-1 code for the language.
finalinherited
- family → NaturalLanguageFamily
-
The language family to which the language belongs.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- internationalName → String
-
An String representing the international name of the object. This is
typically a English name of the ISO object.
no setterinherited
- isConstructed → bool
-
Available on NaturalLanguage, provided by the NaturalLanguageGetters extension
Returns boolean indicating whether this NaturalLanguage is a constructed language.no setter - iso639one → String
-
Available on NaturalLanguage, provided by the NaturalLanguageGetters extension
Returns the ISO 639-1 language code for a NaturalLanguage.no setter - iso639twoB → String?
-
Available on NaturalLanguage, provided by the NaturalLanguageGetters extension
Returns the ISO 639-2/B bibliographic language code for this NaturalLanguage, ornullif none is available.no setter - iso639twoT → String
-
Available on NaturalLanguage, provided by the NaturalLanguageGetters extension
Returns the ISO 639-2/T language code for this NaturalLanguage.no setter - isRightToLeft → bool
-
Whether the language is written right-to-left.
finalinherited
- l10n → LocalizationDelegate
-
Returns the BasicLocalizationDelegate used for handling translations.
no setterinherited
- name → String
-
The name of the language.
finalinherited
-
namesNative
→ List<
String> -
A list of non-empty strings representing the language's native names.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scripts
→ Set<
Script> -
The ISO 15924 scripts used by the language.
finalinherited
Methods
-
compareTo(
NaturalLanguage other) → int -
Compares this object to another object.
inherited
-
copyWith(
{String? bibliographicCode, String? code, String? codeShort, NaturalLanguageFamily? family, bool? isRightToLeft, String? name, List< String> ? namesNative, Set<Script> ? scripts, LocaleMapFunction<String> mapper()?}) → NaturalLanguage -
Available on T, provided by the NaturalLanguageCopyWith extension
Creates a new instance of NaturalLanguage with updated properties. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
{JsonCodec codec = const JsonCodec()}) → String -
Returns a JSON-encoded string representation of the object.
inherited
-
toMap(
) → Map< String, Object> -
Available on NaturalLanguage, provided by the NaturalLanguageJson extension
Converts the NaturalLanguage object to a JSON map. -
toString(
{bool short = true}) → String -
Returns a string representation of this NaturalLanguage object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited